package sun.reflect;

import java.lang.reflect.Field;

class UnsafeIntegerFieldAccessorImpl extends UnsafeFieldAccessorImpl
{
    UnsafeIntegerFieldAccessorImpl(Field field) {
        super(field);
    }
    
    @Override
    public Object get(Object o) throws IllegalArgumentException {
        return new Integer(this.getInt(o));
    }
    
    @Override
    public boolean getBoolean(Object o) throws IllegalArgumentException {
        throw this.newGetBooleanIllegalArgumentException();
    }
    
    @Override
    public byte getByte(Object o) throws IllegalArgumentException {
        throw this.newGetByteIllegalArgumentException();
    }
    
    @Override
    public char getChar(Object o) throws IllegalArgumentException {
        throw this.newGetCharIllegalArgumentException();
    }
    
    @Override
    public short getShort(Object o) throws IllegalArgumentException {
        throw this.newGetShortIllegalArgumentException();
    }
    
    @Override
    public int getInt(Object o) throws IllegalArgumentException {
        this.ensureObj(o);
        return UnsafeIntegerFieldAccessorImpl.unsafe.getInt(o, this.fieldOffset);
    }
    
    @Override
    public long getLong(Object o) throws IllegalArgumentException {
        return (long)this.getInt(o);
    }
    
    @Override
    public float getFloat(Object o) throws IllegalArgumentException {
        return (float)this.getInt(o);
    }
    
    @Override
    public double getDouble(Object o) throws IllegalArgumentException {
        return (double)this.getInt(o);
    }
    
    @Override
    public void set(Object o, Object o2) throws IllegalArgumentException, IllegalAccessException {
        this.ensureObj(o);
        if (this.isFinal) {
            this.throwFinalFieldIllegalAccessException(o2);
        }
        if (o2 == null) {
            this.throwSetIllegalArgumentException(o2);
        }
        if ((o2 instanceof Byte)) {
            UnsafeIntegerFieldAccessorImpl.unsafe.putInt(o, this.fieldOffset, (int)(byte)o2);
            return;
        }
        if ((o2 instanceof Short)) {
            UnsafeIntegerFieldAccessorImpl.unsafe.putInt(o, this.fieldOffset, (int)(short)o2);
            return;
        }
        if ((o2 instanceof Character)) {
            UnsafeIntegerFieldAccessorImpl.unsafe.putInt(o, this.fieldOffset, (int)(char)o2);
            return;
        }
        if ((o2 instanceof Integer)) {
            UnsafeIntegerFieldAccessorImpl.unsafe.putInt(o, this.fieldOffset, (int)o2);
            return;
        }
        this.throwSetIllegalArgumentException(o2);
        return;
    }
    
    @Override
    public void setBoolean(Object o, boolean b) throws IllegalArgumentException, IllegalAccessException {
        this.throwSetIllegalArgumentException(b);
    }
    
    @Override
    public void setByte(Object o, byte b) throws IllegalArgumentException, IllegalAccessException {
        this.setInt(o, (int)b);
    }
    
    @Override
    public void setChar(Object o, char c) throws IllegalArgumentException, IllegalAccessException {
        this.setInt(o, (int)c);
    }
    
    @Override
    public void setShort(Object o, short n) throws IllegalArgumentException, IllegalAccessException {
        this.setInt(o, (int)n);
    }
    
    @Override
    public void setInt(Object o, int x) throws IllegalArgumentException, IllegalAccessException {
        this.ensureObj(o);
        if (this.isFinal) {
            this.throwFinalFieldIllegalAccessException(x);
        }
        UnsafeIntegerFieldAccessorImpl.unsafe.putInt(o, this.fieldOffset, x);
    }
    
    @Override
    public void setLong(Object o, long n) throws IllegalArgumentException, IllegalAccessException {
        this.throwSetIllegalArgumentException(n);
    }
    
    @Override
    public void setFloat(Object o, float n) throws IllegalArgumentException, IllegalAccessException {
        this.throwSetIllegalArgumentException(n);
    }
    
    @Override
    public void setDouble(Object o, double n) throws IllegalArgumentException, IllegalAccessException {
        this.throwSetIllegalArgumentException(n);
    }
}
